# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from ... import _utilities
import typing
# Export this package's modules as members:
from ._enums import *
from .get_key import *
from .get_managed_hsm import *
from .get_mhsm_private_endpoint_connection import *
from .get_private_endpoint_connection import *
from .get_secret import *
from .get_vault import *
from .key import *
from .managed_hsm import *
from .mhsm_private_endpoint_connection import *
from .private_endpoint_connection import *
from .secret import *
from .vault import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from ... import _utilities
from . import outputs

__all__ = [
    'GetBuildpackBindingResult',
    'AwaitableGetBuildpackBindingResult',
    'get_buildpack_binding',
    'get_buildpack_binding_output',
]

@pulumi.output_type
class GetBuildpackBindingResult:
    """
    Buildpack Binding Resource object
    """
    def __init__(__self__, id=None, name=None, properties=None, system_data=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if properties and not isinstance(properties, dict):
            raise TypeError("Expected argument 'properties' to be a dict")
        pulumi.set(__self__, "properties", properties)
        if system_data and not isinstance(system_data, dict):
            raise TypeError("Expected argument 'system_data' to be a dict")
        pulumi.set(__self__, "system_data", system_data)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Fully qualified resource Id for the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the resource.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def properties(self) -> 'outputs.BuildpackBindingPropertiesResponse':
        """
        Properties of a buildpack binding
        """
        return pulumi.get(self, "properties")

    @property
    @pulumi.getter(name="systemData")
    def system_data(self) -> 'outputs.SystemDataResponse':
        """
        Metadata pertaining to creation and last modification of the resource.
        """
        return pulumi.get(self, "system_data")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The type of the resource.
        """
        return pulumi.get(self, "type")


class AwaitableGetBuildpackBindingResult(GetBuildpackBindingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBuildpackBindingResult(
            id=self.id,
            name=self.name,
            properties=self.properties,
            system_data=self.system_data,
            type=self.type)


def get_buildpack_binding(build_service_name: Optional[str] = None,
                          builder_name: Optional[str] = None,
                          buildpack_binding_name: Optional[str] = None,
                          resource_group_name: Optional[str] = None,
                          service_name: Optional[str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBuildpackBindingResult:
    """
    Get a buildpack binding by name.


    :param str build_service_name: The name of the build service resource.
    :param str builder_name: The name of the builder resource.
    :param str buildpack_binding_name: The name of the Buildpack Binding Name
    :param str resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
    :param str service_name: The name of the Service resource.
    """
    __args__ = dict()
    __args__['buildServiceName'] = build_service_name
    __args__['builderName'] = builder_name
    __args__['buildpackBindingName'] = buildpack_binding_name
    __args__['resourceGroupName'] = resource_group_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure-native:appplatform/v20221101preview:getBuildpackBinding', __args__, opts=opts, typ=GetBuildpackBindingResult).value

    return AwaitableGetBuildpackBindingResult(
        id=__ret__.id,
        name=__ret__.name,
        properties=__ret__.properties,
        system_data=__ret__.system_data,
        type=__ret__.type)


@_utilities.lift_output_func(get_buildpack_binding)
def get_buildpack_binding_output(build_service_name: Optional[pulumi.Input[str]] = None,
                                 builder_name: Optional[pulumi.Input[str]] = None,
                                 buildpack_binding_name: Optional[pulumi.Input[str]] = None,
                                 resource_group_name: Optional[pulumi.Input[str]] = None,
                                 service_name: Optional[pulumi.Input[str]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBuildpackBindingResult]:
    """
    Get a buildpack binding by name.


    :param str build_service_name: The name of the build service resource.
    :param str builder_name: The name of the builder resource.
    :param str buildpack_binding_name: The name of the Buildpack Binding Name
    :param str resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
    :param str service_name: The name of the Service resource.
    """
    ...
